Citation
-------------
If you use *swyft* in scientific publications, please include all of the following citations.

.. code-block:: bibtex

   @article{Miller2022,
      doi = {10.21105/joss.04205},
      url = {https://doi.org/10.21105/joss.04205},
      year = {2022},
      publisher = {The Open Journal},
      volume = {7},
      number = {75},
      pages = {4205},
      author = {Benjamin Kurt Miller and Alex Cole and Christoph Weniger and Francesco Nattino and Ou Ku and Meiert W. Grootes},
      title = {swyft: Truncated Marginal Neural Ratio Estimation in Python},
      journal = {Journal of Open Source Software}
   }

   @article{miller2021truncated,
      title={Truncated Marginal Neural Ratio Estimation},
      author={Miller, Benjamin Kurt and Cole, Alex and Forr{\'e}, Patrick and Louppe, Gilles and Weniger, Christoph},
      journal={Advances in Neural Information Processing Systems},
      volume={34},
      year={2021}
   }

   @article{miller2020simulation,
      title={Simulation-efficient marginal posterior estimation with swyft: stop wasting your precious time},
      author={Miller, Benjamin Kurt and Cole, Alex and Louppe, Gilles and Weniger, Christoph},
      journal={Machine Learning and the Physical Sciences: Workshop at the 34th Conference on Neural Information Processing Systems (NeurIPS)},
      year={2020}
   }
